@@ -38,9 +38,8 @@
 
 #include "kpLogCategories.h"
 #include <kiconloader.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
-#include <qapplication.h>
 #include <qbuttongroup.h>
 #include <qgroupbox.h>
 #include <qlabel.h>
@@ -270,7 +269,7 @@ void kpTransformRotateDialog::accept ()
                       " responsiveness and cause other application resource"
                       " problems.</p>"
 
-                      "<p>Are you sure want to rotate the selection?</p></qt>");
+                      "<p>Are you sure you want to rotate the selection?</p></qt>");
 
             caption = i18nc ("@title:window", "Rotate Selection?");
             continueButtonText = i18n ("Rotat&e Selection");
@@ -285,7 +284,7 @@ void kpTransformRotateDialog::accept ()
                   " responsiveness and cause other application resource"
                   " problems.</p>"
 
-                  "<p>Are you sure want to rotate the image?</p></qt>");
+                  "<p>Are you sure you want to rotate the image?</p></qt>");
 
         caption = i18nc ("@title:window", "Rotate Image?");
         continueButtonText = i18n ("Rotat&e Image");
